GedcomMatcher class

Computes best person matches between two GEDCOM datasets.

Constructors

GedcomMatcher()
Creates a matching engine instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

match({required List<PersonRecord> leftPeople, required List<PersonRecord> rightPeople, required MatchOptions options, ProgressCallback? onProgress}) List<MatchResult>
Matches leftPeople against rightPeople and returns best matches.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited